from enum import IntEnum


class EveCategoryId(IntEnum):
    SHIP = 6
    BLUEPRINT = 9
    STRUCTURE = 65
    SKIN = 91


class EveGroupId(IntEnum):
    CHARACTER = 1
    CORPORATION = 2
    SOLAR_SYSTEM = 5
    PLANET = 7
    MOON = 8
    ASTEROID_BELT = 9
    STARGATE = 10
    STATION = 15
    ALLIANCE = 32


# EVE IDs (deprecated, use above enums instead)
EVE_CATEGORY_ID_SHIP = 6
EVE_CATEGORY_ID_BLUEPRINT = 9
EVE_CATEGORY_ID_STRUCTURE = 65
EVE_CATEGORY_ID_SKIN = 91

EVE_GROUP_ID_PLANET = 7
EVE_GROUP_ID_MOON = 8
EVE_GROUP_ID_ASTEROID_BELT = 9
EVE_GROUP_ID_STARGATE = 10
EVE_GROUP_ID_STATION = 15

# ESI
POST_UNIVERSE_NAMES_MAX_ITEMS = 1000
